package com.zcloud.controller.eightwork;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.eightwork.LimitSpaceService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：有限空间台账
 * 作者：luoxiaobao
 * 时间：2021-04-02
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/app/limitspace")
public class AppLimitSpaceController extends BaseController {

	@Autowired
	private LimitSpaceService limitspaceService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "有限空间台账",instructionsOperate = "有限空间台账",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("LIMITSPACE_ID", this.get32UUID());	//主键
		pd.put("CREATOR",pd.get("USER"));	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//创建时间
		pd.put("OPERATOR", pd.get("USER"));	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE", "0");	//是否删除
		limitspaceService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param out
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	@RequiresPermissions("limitspace:del")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "有限空间台账",instructionsOperate = "有限空间台账",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		limitspaceService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "有限空间台账",instructionsOperate = "有限空间台账",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", pd.get("USER"));	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		limitspaceService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "有限空间台账",instructionsOperate = "有限空间台账",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		page.setPd(pd);
		List<PageData>	varList = limitspaceService.list(page);	//列出LimitSpace列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "有限空间台账",instructionsOperate = "有限空间台账",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = limitspaceService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**查询本公司所有有限空间
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/listAllSpace")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "有限空间台账",instructionsOperate = "有限空间台账",instructionsType = "查询本公司所有有限空间")
	public Object listAllSpace() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		List<PageData> varList = limitspaceService.listAll(pd);	//根据ID读取
		map.put("varList", varList);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	@RequiresPermissions("limitspace:del")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "有限空间台账",instructionsOperate = "有限空间台账",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);
			pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
			pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
			//limitspaceService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	@RequiresPermissions("toExcel")
	@LogAnno(menuType= "手机",menuServer= "有限空间台账",instructionsOperate = "有限空间台账",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("编号");	//1
		titles.add("有限空间名称");	//2
		titles.add("有限空间类型");	//3
		titles.add("位置及范围");	//4
		titles.add("主要危险及有害因素");	//5
		titles.add("风险等级");	//6
		titles.add("本有限空间最多作业人数");	//7
		titles.add("是否有应急指导书  0无 1有");	//8
		titles.add("备注");	//9
		titles.add("填报人");	//10
		titles.add("主要负责人");	//11
		titles.add("填报时间");	//12
		titles.add("企业ID");	//13
		titles.add("添加人");	//14
		titles.add("添加时间");	//15
		titles.add("修改人");	//16
		titles.add("修改时间");	//17
		titles.add("是否删除 1-是  0-否");	//18
		dataMap.put("titles", titles);
		List<PageData> varOList = limitspaceService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("NUMBER"));	    //1
			vpd.put("var2", varOList.get(i).getString("NAME"));	    //2
			vpd.put("var3", varOList.get(i).getString("LIMITSPACETYPE"));	    //3
			vpd.put("var4", varOList.get(i).getString("POSITIONSCOPE"));	    //4
			vpd.put("var5", varOList.get(i).getString("PRIMARYHAZARD"));	    //5
			vpd.put("var6", varOList.get(i).getString("RISKGRADE"));	    //6
			vpd.put("var7", varOList.get(i).getString("MAXPERSON"));	    //7
			vpd.put("var8", varOList.get(i).getString("HASINSTRUCTOR"));	    //8
			vpd.put("var9", varOList.get(i).getString("DESCR"));	    //9
			vpd.put("var10", varOList.get(i).getString("INFORMANT"));	    //10
			vpd.put("var11", varOList.get(i).getString("PRINCIPAL"));	    //11
			vpd.put("var12", varOList.get(i).getString("COMPILETIME"));	    //12
			vpd.put("var13", varOList.get(i).getString("CORPINFO_ID"));	    //13
			vpd.put("var14", varOList.get(i).getString("CREATOR"));	    //14
			vpd.put("var15", varOList.get(i).getString("CREATTIME"));	    //15
			vpd.put("var16", varOList.get(i).getString("OPERATOR"));	    //16
			vpd.put("var17", varOList.get(i).getString("OPERATTIME"));	    //17
			vpd.put("var18", varOList.get(i).getString("ISDELETE"));	    //18
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
