package com.zcloud.controller.emergency;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.emergency.EmergencyEquipmentService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：应急装备管理
 * 作者：luoxiaobao
 * 时间：2021-06-20
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/emergencyequipment")
public class EmergencyEquipmentController extends BaseController {

	@Autowired
	private EmergencyEquipmentService emergencyequipmentService;

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions("emergencyequipment:add")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急装备管理",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("EMERGENCYEQUIPMENT_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE", "0");	//是否删除 1-是  0-否
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		emergencyequipmentService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("emergencyequipment:del")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急装备管理",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		emergencyequipmentService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("emergencyequipment:edit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急装备管理",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		emergencyequipmentService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	// @RequiresPermissions("emergencyequipment:list")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急装备管理",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		page.setPd(pd);
		List<PageData>	varList = emergencyequipmentService.list(page);	//列出EmergencyEquipment列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	// @RequiresPermissions("emergencyequipment:edit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急装备管理",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = emergencyequipmentService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("emergencyequipment:del")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急装备管理",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);	//待删除ids
			emergencyequipmentService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急装备管理",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("装备名称");	//1
		titles.add("装备类别");	//2
		titles.add("规格型号");	//3
		titles.add("技术性能指标");	//4
		titles.add("保养周期");	//5
		titles.add("有效期");	//6
		titles.add("用途");	//7
		titles.add("用途说明");	//8
		titles.add("存放场所");	//9
		titles.add("负责保管人姓名");	//10
		titles.add("负责保管人电话");	//11
		titles.add("是否删除");	//12
		titles.add("修改人");	//13
		titles.add("修改时间");	//14
		titles.add("添加时间");	//15
		titles.add("添加人");	//16
		dataMap.put("titles", titles);
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData> varOList = emergencyequipmentService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("EQUIP_NAME"));	    //1
			vpd.put("var2", varOList.get(i).getString("CATEGORY"));	    //2
			vpd.put("var3", varOList.get(i).getString("SPEC"));	    //3
			vpd.put("var4", varOList.get(i).getString("EQUIP_PERFORMANCE"));	    //4
			vpd.put("var5", varOList.get(i).getString("MAINTAIN_DATE"));	    //5
			vpd.put("var6", varOList.get(i).getString("VALIDATE_DATE"));	    //6
			vpd.put("var7", varOList.get(i).getString("USE"));	    //7
			vpd.put("var8", varOList.get(i).getString("USE_DESC"));	    //8
			vpd.put("var9", varOList.get(i).getString("STORAGE_PLACE"));	    //9
			vpd.put("var10", varOList.get(i).getString("STORAGE_PERSON_NAME"));	    //10
			vpd.put("var11", varOList.get(i).getString("STORAGE_PERSON_PHONE"));	    //11
			vpd.put("var12", varOList.get(i).get("ISDELETE").toString());	//12
			vpd.put("var13", varOList.get(i).getString("OPERATOR"));	    //13
			vpd.put("var14", varOList.get(i).getString("OPERATTIME"));	    //14
			vpd.put("var15", varOList.get(i).getString("CREATTIME"));	    //15
			vpd.put("var16", varOList.get(i).getString("CREATOR"));	    //16
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
