package com.zcloud.controller.emergency;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.emergency.EmergencyTeamService;
import com.zcloud.util.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：应急救援队伍管理
 * 作者：luoxiaobao
 * 时间：2021-06-20
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/emergencyteam")
public class EmergencyTeamController extends BaseController {

	@Autowired
	private EmergencyTeamService emergencyteamService;


	@RequestMapping(value="/emergencyIndex")
	// @RequiresPermissions("emergencyteam:add")
	@ResponseBody
	public Object emergencyIndex()  {
		PageData pageData = this.getPageData();
		pageData.put("CORPINFO_ID",Jurisdiction.getCORPINFO_ID());
		return ReturnMap.ok().put("data",emergencyteamService.emergencyIndex(pageData));
	}

	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	// @RequiresPermissions("emergencyteam:add")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急救援队伍管理",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("EMERGENCYTEAM_ID", this.get32UUID());	//主键
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("ISDELETE", "0");	//是否删除 1-是  0-否
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		emergencyteamService.save(pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("emergencyteam:del")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急救援队伍管理",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		emergencyteamService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("emergencyteam:edit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急救援队伍管理",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		emergencyteamService.edit(pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	// @RequiresPermissions("emergencyteam:list")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急救援队伍管理",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		page.setPd(pd);
		List<PageData>	varList = emergencyteamService.list(page);	//列出EmergencyTeam列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	// @RequiresPermissions("emergencyteam:edit")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急救援队伍管理",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = emergencyteamService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("emergencyteam:del")
	@ResponseBody
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急救援队伍管理",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String ArrayDATA_IDS[] = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);	//待删除ids
			emergencyteamService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	@LogAnno(menuType= "综合管理",menuServer= "应急资源管理",instructionsOperate = "应急救援队伍管理",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("队伍名称");	//1
		titles.add("队伍类别");	//2
		titles.add("队伍属性");	//3
		titles.add("队伍级别");	//4
		titles.add("队伍等级");	//5
		titles.add("成立日期");	//6
		titles.add("地址");	//7
		titles.add("服务区域");	//8
		titles.add("队伍负责人姓名");	//9
		titles.add("队伍负责人电话");	//10
		titles.add("应急值班电话");	//11
		titles.add("总人数");	//12
		titles.add("指战人数");	//13
		titles.add("车辆数");	//14
		titles.add("后勤人数");	//15
		titles.add("队员信息");	//16
		titles.add("救援专业");	//17
		titles.add("专长描述");	//18
		titles.add("队伍简介");	//19
		titles.add("是否删除");	//20
		titles.add("修改人");	//21
		titles.add("修改时间");	//22
		titles.add("添加时间");	//23
		titles.add("添加人");	//24
		dataMap.put("titles", titles);
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData> varOList = emergencyteamService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("TEAM_NAME"));	    //1
			vpd.put("var2", varOList.get(i).getString("TEAM_CATEGORY"));	    //2
			vpd.put("var3", varOList.get(i).getString("TEAM_PROPERTY"));	    //3
			vpd.put("var4", varOList.get(i).getString("TEAM_LEVEL"));	    //4
			vpd.put("var5", varOList.get(i).getString("TEAM_GRADE"));	    //5
			vpd.put("var6", varOList.get(i).getString("TEAM_CREATE_TIME"));	    //6
			vpd.put("var7", varOList.get(i).getString("ADDRESS"));	    //7
			vpd.put("var8", varOList.get(i).getString("SERVICE_PLACE"));	    //8
			vpd.put("var9", varOList.get(i).getString("TEAM_LEADER_NAME"));	    //9
			vpd.put("var10", varOList.get(i).getString("TEAM_LEADER_PHONE"));	    //10
			vpd.put("var11", varOList.get(i).getString("DUTY_TELEPHONE"));	    //11
			vpd.put("var12", varOList.get(i).get("TOTLE_PERSON_NUM").toString());	//12
			vpd.put("var13", varOList.get(i).get("COMMANDER_NUM").toString());	//13
			vpd.put("var14", varOList.get(i).get("CAR_NUM").toString());	//14
			vpd.put("var15", varOList.get(i).get("LOGISTICS_PERSON_NUM").toString());	//15
			vpd.put("var16", varOList.get(i).getString("TEAM_MEMBER_INFO"));	    //16
			vpd.put("var17", varOList.get(i).getString("SPECIAL_TYPE"));	    //17
			vpd.put("var18", varOList.get(i).getString("SPECIAL_DESC"));	    //18
			vpd.put("var19", varOList.get(i).getString("TEAM_DESC"));	    //19
			vpd.put("var20", varOList.get(i).get("ISDELETE").toString());	//20
			vpd.put("var21", varOList.get(i).getString("OPERATOR"));	    //21
			vpd.put("var22", varOList.get(i).getString("OPERATTIME"));	    //22
			vpd.put("var23", varOList.get(i).getString("CREATTIME"));	    //23
			vpd.put("var24", varOList.get(i).getString("CREATOR"));	    //24
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
