package com.zcloud.controller.majordangersource;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.majordangersource.MajordangersourceDisposalService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：重大危险源应急处置
 * 作者：luoxiaobao
 * 时间：2022-05-04
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/majordangersourcedisposal")
public class MajordangersourceDisposalController extends BaseController {

	@Autowired
	private MajordangersourceDisposalService majordangersourcedisposalService;


	/**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/findValidateData")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "实时数据监测",instructionsType = "去修改页面获取数据")
	public Object findValidateData() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		List<PageData> pdList = majordangersourcedisposalService.listAll(pd);	//根据ID读取
		map.put("pd", pdList.size()>0 ? pdList.get(0) : "");
		map.put("result", errInfo);
		return map;
	}


	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "实时数据监测",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("MAJORDANGERSOURCE_DISPOSAL_ID", this.get32UUID());	//主键
		pd.put("DISPOSAL_TIME", DateUtil.date2Str(new Date()));	//处置生成时间
		pd.put("DISPOSAL_STATUS", "-1");	//处置状态(-1.未处置 0.报警升级 1.完成处置)
		pd.put("ISDELETE", "0");	//是否删除(0:有效 1：删除)
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", DateUtil.date2Str(new Date()));	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		majordangersourcedisposalService.save(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "实时数据监测",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		majordangersourcedisposalService.edit(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}



	/**报警升级
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/up")
	@ResponseBody
	public Object up() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String date = DateUtil.date2Str(new Date());
		pd.put("OPERATTIME", date);	//修改时间
		majordangersourcedisposalService.upLevel(pd);

		pd.put("MAJORDANGERSOURCE_DISPOSAL_ID", this.get32UUID());	//主键
		pd.put("DISPOSAL_TIME", date);	//处置生成时间
		pd.put("DISPOSAL_STATUS", "-1");	//处置状态(-1.未处置 0.报警升级 1.完成处置)
		pd.put("ISDELETE", "0");	//是否删除(0:有效 1：删除)
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", date);	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", date);	//修改时间
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		majordangersourcedisposalService.save(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "实时数据监测",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		page.setPd(pd);
		List<PageData>	varList = majordangersourcedisposalService.list(page);	//列出MajordangersourceDisposal列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	/**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	@ResponseBody
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = majordangersourcedisposalService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goShow")
	@ResponseBody
	@LogAnno(menuType= "监测预警",menuServer= "重大危险源监测预警",instructionsOperate = "实时数据监测",instructionsType = "去修改页面获取数据")
	public Object goShow() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = majordangersourcedisposalService.showById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
	// @RequiresPermissions("majordangersourcedisposal:del")
	@ResponseBody
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		majordangersourcedisposalService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("majordangersourcedisposal:del")
	@ResponseBody
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String[] ArrayDATA_IDS = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);	//待删除ids
			majordangersourcedisposalService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("重大危险源ID");	//1
		titles.add("报警类型");	//2
		titles.add("报警值");	//3
		titles.add("报警级别（1.一级 2.二级 3.三级 4.四级）");	//4
		titles.add("报警阈值下限");	//5
		titles.add("报警阈值上限");	//6
		titles.add("处置人");	//7
		titles.add("处置方式");	//8
		titles.add("处置描述");	//9
		titles.add("处置描述时间");	//10
		titles.add("处置状态(-1.未处置 0.报警升级 1.完成处置)");	//11
		titles.add("处置完成时间");	//12
		titles.add("是否删除(0:有效 1：删除)");	//13
		titles.add("添加人");	//14
		titles.add("添加时间");	//15
		titles.add("修改人");	//16
		titles.add("修改时间");	//17
		titles.add("企业ID");	//18
		dataMap.put("titles", titles);
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData> varOList = majordangersourcedisposalService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("MAJORDANGERSOURCE_ID"));	    //1
			vpd.put("var2", varOList.get(i).getString("ALARM_TYPE"));	    //2
			vpd.put("var3", varOList.get(i).getString("ALARM_VALUE"));	    //3
			vpd.put("var4", varOList.get(i).getString("ALARM_LEVEL"));	    //4
			vpd.put("var5", varOList.get(i).getString("ALARM_RANGE_MIN"));	    //5
			vpd.put("var6", varOList.get(i).getString("ALARM_RANGE_MAX"));	    //6
			vpd.put("var7", varOList.get(i).getString("DISPOSAL_PERSON"));	    //7
			vpd.put("var8", varOList.get(i).getString("DISPOSAL_METHOD"));	    //8
			vpd.put("var9", varOList.get(i).getString("DISPOSAL_DESC"));	    //9
			vpd.put("var10", varOList.get(i).getString("DISPOSAL_TIME"));	    //10
			vpd.put("var11", varOList.get(i).getString("DISPOSAL_STATUS"));	    //11
			vpd.put("var12", varOList.get(i).getString("DISPOSAL_TIME_OVER"));	    //12
			vpd.put("var13", varOList.get(i).getString("ISDELETE"));	    //13
			vpd.put("var14", varOList.get(i).getString("CREATOR"));	    //14
			vpd.put("var15", varOList.get(i).getString("CREATTIME"));	    //15
			vpd.put("var16", varOList.get(i).getString("OPERATOR"));	    //16
			vpd.put("var17", varOList.get(i).getString("OPERATTIME"));	    //17
			vpd.put("var18", varOList.get(i).getString("CORPINFO_ID"));	    //18
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

}
