package com.zcloud.controller.riskWarning;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.riskWarning.RiskWarningService;
import com.zcloud.service.system.ImgFilesService;
import com.zcloud.util.*;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.apache.tools.zip.ZipEntry;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletResponse;
import java.io.ByteArrayOutputStream;
import java.io.FileNotFoundException;
import java.io.OutputStream;
import java.nio.charset.StandardCharsets;
import java.util.*;
import java.util.zip.ZipOutputStream;

/**
 * 说明：风险提示
 * 作者：luoxiaobao
 * 时间：2021-04-27
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/riskwarning")
public class RiskWarningController extends BaseController {

    @Autowired
    private RiskWarningService riskwarningService;
    @Autowired
    private ImgFilesService imgfilesService;

    /**
     * 新增
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/add")
    // @RequiresPermissions("riskwarning:add")
    @ResponseBody
    @LogAnno(menuType = "双重预控", menuServer = "风险提示", instructionsOperate = "风险四色图", instructionsType = "新增")

    public Object add(@RequestParam(value = "FFILE", required = false) MultipartFile file) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("RISKWARNING_ID", this.get32UUID());    //主键
        pd.put("CREATOR", Jurisdiction.getUsername());    //添加人
        pd.put("CREATTIME", DateUtil.date2Str(new Date()));    //添加时间
        pd.put("OPERATOR", Jurisdiction.getUsername());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        pd.put("ISDELETE", "0");    //是否删除 1-是  0-否
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
        riskwarningService.save(pd);
        map.put("result", errInfo);
        map.put("pd", pd);
        return map;
    }

    /**
     * 删除
     *
     * @param out
     * @throws Exception
     */
    @RequestMapping(value = "/delete")
    // @RequiresPermissions("riskwarning:del")
    @ResponseBody
    @LogAnno(menuType = "双重预控", menuServer = "风险提示", instructionsOperate = "风险四色图", instructionsType = "删除")
    public Object delete() throws Exception {
        Map<String, String> map = new HashMap<String, String>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        riskwarningService.delete(pd);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 修改
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/edit")
    // @RequiresPermissions("riskwarning:edit")
    @ResponseBody
    @LogAnno(menuType = "双重预控", menuServer = "风险提示", instructionsOperate = "风险四色图", instructionsType = "修改")
    public Object edit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        riskwarningService.edit(pd);
        map.put("result", errInfo);
        map.put("pd", pd);
        return map;
    }

    /**
     * 列表
     *
     * @param page
     * @throws Exception
     */
    @RequestMapping(value = "/list")
    // @RequiresPermissions("riskwarning:list")
    @ResponseBody
    @LogAnno(menuType = "双重预控", menuServer = "风险提示", instructionsOperate = "风险四色图", instructionsType = "列表")

    public Object list(Page page) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String KEYWORDS = pd.getString("KEYWORDS");                        //关键词检索条件
        if (Tools.notEmpty(KEYWORDS)) pd.put("KEYWORDS", KEYWORDS.trim());
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
        page.setPd(pd);
        List<PageData> varList = riskwarningService.list(page);    //列出RiskWarning列表
        if (varList != null && varList.size() > 0) {
            for (PageData var : varList) {
                PageData pd2 = new PageData();
                pd2.put("FOREIGN_KEY", var.getString("RISKWARNING_ID"));
                List<PageData> imgs = imgfilesService.listAll(pd2);//营业执照图片
                var.put("imgs", imgs);
            }
        }
        map.put("varList", varList);
        map.put("page", page);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 去修改页面获取数据
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/goEdit")
    // @RequiresPermissions("riskwarning:edit")
    @ResponseBody
    @LogAnno(menuType = "双重预控", menuServer = "风险提示", instructionsOperate = "风险四色图", instructionsType = "去修改页面获取数据")
    public Object goEdit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();

        PageData pd2 = new PageData();
        pd2.put("FOREIGN_KEY", pd.getString("RISKWARNING_ID"));
        pd2.put("TYPE", pd.get("TYPE"));
        List<PageData> imgs = imgfilesService.listAll(pd2);//营业执照图片
        pd = riskwarningService.findById(pd);    //根据ID读取


        map.put("pd", pd);
        map.put("result", errInfo);
        map.put("imgs", imgs);
        return map;
    }

    /**
     * 批量删除
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/deleteAll")
    // @RequiresPermissions("riskwarning:del")
    @ResponseBody
    @LogAnno(menuType = "双重预控", menuServer = "风险提示", instructionsOperate = "风险四色图", instructionsType = "批量删除")
    public Object deleteAll() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String DATA_IDS = pd.getString("DATA_IDS");
        if (Tools.notEmpty(DATA_IDS)) {
            String ArrayDATA_IDS[] = DATA_IDS.split(",");
            riskwarningService.deleteAll(ArrayDATA_IDS);
            errInfo = "success";
        } else {
            errInfo = "error";
        }
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 下载
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/goDownload")
    @ResponseBody
    @LogAnno(menuType = "双重预控", menuServer = "风险提示", instructionsOperate = "风险四色图", instructionsType = "下载")
    public void goDownload(HttpServletResponse response) throws Exception {
        PageData pd = this.getPageData();
        PageData pd2 = new PageData();
        pd2.put("FOREIGN_KEY", pd.getString("RISKWARNING_ID"));
        //pd2.put("TYPE",pd.get("TYPE"));
        List<PageData> imgs = imgfilesService.listAll(pd2);
		//风险四色图图片
		try {
            ByteArrayOutputStream bos = new ByteArrayOutputStream();
            ZipOutputStream zos = new ZipOutputStream(bos);
            UrlFilesToZip s = new UrlFilesToZip();
            for (PageData oneFile : imgs) {
                if (oneFile != null && oneFile.get("FILEPATH") != null && Tools.notEmpty(oneFile.get("FILEPATH").toString())) {
                    zos.putNextEntry(new ZipEntry(oneFile.get("FILEPATH").toString().substring(oneFile.get("FILEPATH").toString().length() < 85 ? 28 : 61)));
                    byte[] bytes = s.getImageFromURL(Const.HTTPFILEURL + oneFile.get("FILEPATH").toString());
                    zos.write(bytes, 0, bytes.length);
                    zos.closeEntry();
                }
            }
            zos.close();
            response.setHeader("Content-Disposition", "attachment; filename=\"" + DateUtil.date2Str(new Date()) + ".zip\"");
            response.setContentType("application/octet-stream;charset=UTF-8");
            OutputStream os = response.getOutputStream();
            os.write(bos.toByteArray());
            os.close();
        } catch (FileNotFoundException ex) {
            ex.printStackTrace();
            //logger.error("FileNotFoundException", ex);
        } catch (Exception ex) {
            ex.printStackTrace();
            //logger.error("Exception", ex);
        }






     /*

		response.reset();
	    response.setHeader("Content-Disposition", "attachment; filename=\"" + zipName + "\"");
	    response.setContentType("application/octet-stream;charset=UTF-8");
        ZipOutputStream out = new ZipOutputStream(response.getOutputStream());
        try {

                for(PageData file : imgs) {
                	System.out.println(Const.HTTPFILEURL+file.get("FILEPATH").toString());
                	ZipUtils.doCompress(Const.HTTPFILEURL+file.get("FILEPATH").toString(), out);
                    response.flushBuffer();
                }
        } catch (Exception e) {
            e.printStackTrace();
        }finally{
            out.close();
        }*/
		/*pd = riskwarningService.findById(pd);
		String FILEPATH = pd.get("FILEPATH").toString();
		System.out.println(FILEPATH.length());
		FileDownload.mfFileDownload(response, Const.HTTPFILEURL + FILEPATH, FILEPATH.substring(FILEPATH.length()<85?28:61, FILEPATH.length()));*/
    }

    /**
     * 导出到excel
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/excel")
    @LogAnno(menuType = "双重预控", menuServer = "风险提示", instructionsOperate = "风险四色图", instructionsType = "导出到excel")
    public ModelAndView exportExcel() throws Exception {
        ModelAndView mv = new ModelAndView();
        PageData pd = new PageData();
        pd = this.getPageData();
        Map<String, Object> dataMap = new HashMap<String, Object>();
        List<String> titles = new ArrayList<String>();
        titles.add("文件名");    //1
        titles.add("文件大小");    //2
        titles.add("类型");    //3
        titles.add("添加人");    //4
        titles.add("添加时间");    //5
        titles.add("修改人");    //6
        titles.add("修改时间");    //7
        titles.add("是否删除 1-是  0-否");    //8
        dataMap.put("titles", titles);
        List<PageData> varOList = riskwarningService.listAll(pd);
        List<PageData> varList = new ArrayList<PageData>();
        for (int i = 0; i < varOList.size(); i++) {
            PageData vpd = new PageData();
            vpd.put("var1", varOList.get(i).getString("NAME"));        //1
            vpd.put("var2", varOList.get(i).getString("FILESIZE"));        //2
            vpd.put("var3", varOList.get(i).getString("TYPE"));        //3
            vpd.put("var4", varOList.get(i).getString("CREATOR"));        //4
            vpd.put("var5", varOList.get(i).getString("CREATTIME"));        //5
            vpd.put("var6", varOList.get(i).getString("OPERATOR"));        //6
            vpd.put("var7", varOList.get(i).getString("OPERATTIME"));        //7
            vpd.put("var8", varOList.get(i).getString("ISDELETE"));        //8
            varList.add(vpd);
        }
        dataMap.put("varList", varList);
        ObjectExcelView erv = new ObjectExcelView();
        mv = new ModelAndView(erv, dataMap);
        return mv;
    }

}
