package com.zcloud.controller.task;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.task.CourseExamService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：课程考试
 * 作者：luoxiaobao
 * 时间：2021-09-13
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/app/courseexam")
public class AppCourseExamController extends BaseController {

	@Autowired
	private CourseExamService courseexamService;



	/**交卷
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/submit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程考试",instructionsOperate = "课程考试",instructionsType = "交卷")
	public Object submit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("COURSEEXAM_ID", this.get32UUID());	//主键
		pd.put("USER_ID", pd.getString("USER_ID"));	//添加人
		String nowDate = DateUtil.date2Str(new Date());
//		pd.put("EXAMTIME", nowDate);	//考试时间
		pd.put("EXAMQUESTIONRIGHT", "0");	//考试对题数
		pd.put("EXAMQUESTIONWRONG", "0");	//考试错题数
		pd.put("EXAMSCORE", "0");	//考试得分
		pd.put("CREATOR", pd.getString("USERNAME"));	//添加人
		pd.put("CREATTIME", nowDate);	//添加时间
		pd.put("OPERATOR", pd.getString("USERNAME"));	//修改人
		pd.put("OPERATTIME", nowDate);	//修改时间
		pd.put("ISDELETE", "0");	//是否删除(0:有效 1：删除)
		pd.put("CORPINFO_ID", pd.getString("CORPINFO_ID"));	//企业ID
		pd = courseexamService.submit(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}











	/**新增
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/add")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程考试",instructionsOperate = "课程考试",instructionsType = "新增")
	public Object add() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("COURSEEXAM_ID", this.get32UUID());	//主键
		pd.put("USER_ID", Jurisdiction.getUSER_ID());	//添加人
		String nowDate = DateUtil.date2Str(new Date());
		pd.put("EXAMTIME", nowDate);	//考试时间
		pd.put("EXAMQUESTIONRIGHT", "0");	//考试对题数
		pd.put("EXAMQUESTIONWRONG", "0");	//考试错题数
		pd.put("EXAMSCORE", "0");	//考试得分
		pd.put("CREATOR", Jurisdiction.getUsername());	//添加人
		pd.put("CREATTIME", nowDate);	//添加时间
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", nowDate);	//修改时间
		pd.put("ISDELETE", "0");	//是否删除(0:有效 1：删除)
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		courseexamService.save(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/delete")
//	// @RequiresPermissions("courseexam:del")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程考试",instructionsOperate = "课程考试",instructionsType = "删除")
	public Object delete() throws Exception{
		Map<String,String> map = new HashMap<String,String>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		courseexamService.delete(pd);
		map.put("result", errInfo);				//返回结果
		return map;
	}

	/**修改
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/edit")
	// @RequiresPermissions("courseexam:edit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程考试",instructionsOperate = "课程考试",instructionsType = "修改")
	public Object edit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		courseexamService.edit(pd);
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	/**列表
	 * @param page
	 * @throws Exception
	 */
	@RequestMapping(value="/list")
	// @RequiresPermissions("courseexam:list")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程考试",instructionsOperate = "课程考试",instructionsType = "列表")
	public Object list(Page page) throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		String KEYWORDS = pd.getString("KEYWORDS");						//关键词检索条件
		if(Tools.notEmpty(KEYWORDS))pd.put("KEYWORDS", KEYWORDS.trim());
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		page.setPd(pd);
		List<PageData>	varList = courseexamService.list(page);	//列出CourseExam列表
		map.put("varList", varList);
		map.put("page", page);
		map.put("result", errInfo);
		return map;
	}

	 /**去修改页面获取数据
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/goEdit")
	// @RequiresPermissions("courseexam:edit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程考试",instructionsOperate = "课程考试",instructionsType = "去修改页面获取数据")
	public Object goEdit() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = courseexamService.findById(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

	 /**批量删除
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/deleteAll")
	// @RequiresPermissions("courseexam:del")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程考试",instructionsOperate = "课程考试",instructionsType = "批量删除")
	public Object deleteAll() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd.put("OPERATOR", Jurisdiction.getUsername());	//修改人
		pd.put("OPERATTIME", DateUtil.date2Str(new Date()));	//修改时间
		String DATA_IDS = pd.getString("DATA_IDS");
		if(Tools.notEmpty(DATA_IDS)){
			String[] ArrayDATA_IDS = DATA_IDS.split(",");
			pd.put("ArrayDATA_IDS", ArrayDATA_IDS);	//待删除ids
			courseexamService.deleteAll(pd);
			errInfo = "success";
		}else{
			errInfo = "error";
		}
		map.put("result", errInfo);				//返回结果
		return map;
	}

	 /**导出到excel
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/excel")
	// @RequiresPermissions("toExcel")
	@LogAnno(menuType= "手机",menuServer= "课程考试",instructionsOperate = "课程考试",instructionsType = "导出到excel")
	public ModelAndView exportExcel() throws Exception{
		ModelAndView mv = new ModelAndView();
		PageData pd = new PageData();
		pd = this.getPageData();
		Map<String,Object> dataMap = new HashMap<String,Object>();
		List<String> titles = new ArrayList<String>();
		titles.add("课程ID");	//1
		titles.add("课程试卷ID");	//2
		titles.add("学员ID");	//3
		titles.add("考试时间");	//4
		titles.add("考试总题数");	//5
		titles.add("考试对题数");	//6
		titles.add("考试错题数");	//7
		titles.add("考试得分");	//8
		titles.add("添加人");	//9
		titles.add("添加时间");	//10
		titles.add("修改人");	//11
		titles.add("修改时间");	//12
		titles.add("是否删除(0:有效 1：删除)");	//13
		titles.add("企业ID");	//14
		dataMap.put("titles", titles);
		pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());	//企业ID
		List<PageData> varOList = courseexamService.listAll(pd);
		List<PageData> varList = new ArrayList<PageData>();
		for(int i=0;i<varOList.size();i++){
			PageData vpd = new PageData();
			vpd.put("var1", varOList.get(i).getString("CURRICULUM_ID"));	    //1
			vpd.put("var2", varOList.get(i).getString("COURSEPAPERS_ID"));	    //2
			vpd.put("var3", varOList.get(i).getString("USER_ID"));	    //3
			vpd.put("var4", varOList.get(i).getString("EXAMTIME"));	    //4
			vpd.put("var5", varOList.get(i).getString("EXAMQUESTIONNUM"));	    //5
			vpd.put("var6", varOList.get(i).getString("EXAMQUESTIONRIGHT"));	    //6
			vpd.put("var7", varOList.get(i).getString("EXAMQUESTIONWRONG"));	    //7
			vpd.put("var8", varOList.get(i).getString("EXAMSCORE"));	    //8
			vpd.put("var9", varOList.get(i).getString("CREATOR"));	    //9
			vpd.put("var10", varOList.get(i).getString("CREATTIME"));	    //10
			vpd.put("var11", varOList.get(i).getString("OPERATOR"));	    //11
			vpd.put("var12", varOList.get(i).getString("OPERATTIME"));	    //12
			vpd.put("var13", varOList.get(i).getString("ISDELETE"));	    //13
			vpd.put("var14", varOList.get(i).getString("CORPINFO_ID"));	    //14
			varList.add(vpd);
		}
		dataMap.put("varList", varList);
		ObjectExcelView erv = new ObjectExcelView();
		mv = new ModelAndView(erv,dataMap);
		return mv;
	}

	/**试卷答题展示
	 * @param
	 * @throws Exception
	 */
	@RequestMapping(value="/findResult")
//	// @RequiresPermissions("courseexam:edit")
	@ResponseBody
	@LogAnno(menuType= "手机",menuServer= "课程考试",instructionsOperate = "课程考试",instructionsType = "试卷答题展示")
	public Object findResult() throws Exception{
		Map<String,Object> map = new HashMap<String,Object>();
		String errInfo = "success";
		PageData pd = new PageData();
		pd = this.getPageData();
		pd = courseexamService.findResult(pd);	//根据ID读取
		map.put("pd", pd);
		map.put("result", errInfo);
		return map;
	}

}
