package com.zcloud.controller.task;

import com.zcloud.controller.base.BaseController;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.logs.LogAnno;
import com.zcloud.service.task.CourseStudyVideoRecordService;
import com.zcloud.service.task.StageStudentRelationService;
import com.zcloud.util.DateUtil;
import com.zcloud.util.Jurisdiction;
import com.zcloud.util.ObjectExcelView;
import com.zcloud.util.Tools;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.*;

/**
 * 说明：课程学习视频记录
 * 作者：luoxiaobao
 * 时间：2021-11-24
 * 官网：www.zcloudchina.com
 */
@Controller
@RequestMapping("/app/coursestudyvideorecord")
public class AppCourseStudyVideoRecordController extends BaseController {

    @Autowired
    private CourseStudyVideoRecordService coursestudyvideorecordService;
    @Autowired
    private StageStudentRelationService stageStudentRelationService;

    /**
     * 保存（新增或修改）
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/save")
    @ResponseBody
    @LogAnno(menuType = "手机", menuServer = "课程学习视频记录", instructionsOperate = "课程学习视频记录", instructionsType = "保存")
    public Object save() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        Boolean isLearned = false;
        List<PageData> list = coursestudyvideorecordService.listAll(pd);
        if (list.isEmpty()) {
            pd.put("COURSESTUDYVIDEORECORD_ID", this.get32UUID());    //主键
            if ("1".equals(pd.get("IS_END"))) {
                pd.put("PLAYCOUNT", 1);    //播放次数初始化
            } else {
                pd.put("PLAYCOUNT", 0);    //播放次数初始化
                pd.put("RESOURCETIME", 0);    //播放时间初始化
            }
            pd.put("CREATOR", pd.getString("USERNAME"));    //添加人
            pd.put("CREATTIME", DateUtil.date2Str(new Date()));    //添加时间
            pd.put("OPERATOR", pd.getString("USERNAME"));    //修改人
            pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
            pd.put("ISDELETE", "0");    //是否删除(0:有效 1：删除)
            pd.put("CORPINFO_ID", pd.getString("CORPINFO_ID"));    //企业ID
            coursestudyvideorecordService.save(pd);
        } else {
            PageData editPd = list.get(0);
            // 资料课件
            if ("1".equals(pd.getString("TYPE"))) {
                if (Double.parseDouble(pd.getString("RESOURCETIME")) >= Double.parseDouble(editPd.getString("RESOURCETIME"))) {
                    editPd.put("RESOURCETIME", pd.get("RESOURCETIME"));
                    //播放时间
                }
            }else {
                editPd.put("RESOURCETIME", pd.get("RESOURCETIME"));
            }

            if (!editPd.get("PLAYCOUNT").equals(0)) {
                isLearned = true;
            }
            if (pd.get("IS_END").equals("1")) {
                editPd.put("PLAYCOUNT", ((int) editPd.get("PLAYCOUNT")) + 1);    //播放次数初始化
            }

            editPd.put("OPERATOR", pd.getString("USERNAME"));    //修改人
            editPd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
            // 如果前端 传过来的时间比库里存的时间小 哪么 不更新。用最长的时间
            coursestudyvideorecordService.editResourceTime(editPd);
            pd.put("PLAYCOUNT", editPd.get("PLAYCOUNT"));
        }

        if ("1".equals(pd.get("IS_END").toString()) && !isLearned) {
            List<PageData> countAllList = coursestudyvideorecordService.listAllByCount(pd);
            Integer count = countAllList.size();
            Double CLASSHOUR = 0d;
            for (PageData p : countAllList) {
                CLASSHOUR += Double.parseDouble(p.get("CLASSHOUR").toString());
            }
            pd.put("COMPLETE_COURSEWARE", count);
            pd.put("COMPLETE_CLASSHOUR", CLASSHOUR);
//			pd.put("STUDYTASK_ID",pd.get("CURRICULUM_ID"));
            stageStudentRelationService.updateClassHourAndCount(pd);
        }
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 修改
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/getVideoProgress")
    @ResponseBody
    @LogAnno(menuType = "手机", menuServer = "课程学习视频记录", instructionsOperate = "课程学习视频记录", instructionsType = "修改")
    public Object getVideoProgress() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        List<PageData> list = coursestudyvideorecordService.listAll(pd);
        if (list.isEmpty()) {
            map.put("pd", "");
        } else {
            map.put("pd", list.get(0));
        }
        map.put("result", errInfo);
        return map;
    }

    /**
     * 新增
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/add")
    @ResponseBody
    @LogAnno(menuType = "手机", menuServer = "课程学习视频记录", instructionsOperate = "课程学习视频记录", instructionsType = "新增")
    public Object add() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("COURSESTUDYVIDEORECORD_ID", this.get32UUID());    //主键
        pd.put("CREATOR", Jurisdiction.getUsername());    //添加人
        pd.put("CREATTIME", DateUtil.date2Str(new Date()));    //添加时间
        pd.put("OPERATOR", Jurisdiction.getUsername());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        pd.put("ISDELETE", "");    //是否删除(0:有效 1：删除)
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());    //企业ID
        coursestudyvideorecordService.save(pd);
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 删除
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/delete")
    @ResponseBody
    @LogAnno(menuType = "手机", menuServer = "课程学习视频记录", instructionsOperate = "课程学习视频记录", instructionsType = "删除")
    public Object delete() throws Exception {
        Map<String, String> map = new HashMap<String, String>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("OPERATOR", Jurisdiction.getUsername());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        coursestudyvideorecordService.delete(pd);
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 修改
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/edit")
    @ResponseBody
    @LogAnno(menuType = "手机", menuServer = "课程学习视频记录", instructionsOperate = "课程学习视频记录", instructionsType = "修改")
    public Object edit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("OPERATOR", Jurisdiction.getUsername());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        coursestudyvideorecordService.edit(pd);
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 列表
     *
     * @param page
     * @throws Exception
     */
    @RequestMapping(value = "/list")
    @ResponseBody
    @LogAnno(menuType = "手机", menuServer = "课程学习视频记录", instructionsOperate = "课程学习视频记录", instructionsType = "列表")
    public Object list(Page page) throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        String KEYWORDS = pd.getString("KEYWORDS");                        //关键词检索条件
        if (Tools.notEmpty(KEYWORDS)) pd.put("KEYWORDS", KEYWORDS.trim());
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());    //企业ID
        page.setPd(pd);
        List<PageData> varList = coursestudyvideorecordService.list(page);    //列出CourseStudyVideoRecord列表
        map.put("varList", varList);
        map.put("page", page);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 去修改页面获取数据
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/goEdit")
    @ResponseBody
    @LogAnno(menuType = "手机", menuServer = "课程学习视频记录", instructionsOperate = "课程学习视频记录", instructionsType = "去修改页面获取数据")
    public Object goEdit() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd = coursestudyvideorecordService.findById(pd);    //根据ID读取
        map.put("pd", pd);
        map.put("result", errInfo);
        return map;
    }

    /**
     * 批量删除
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/deleteAll")
    @ResponseBody
    @LogAnno(menuType = "手机", menuServer = "课程学习视频记录", instructionsOperate = "课程学习视频记录", instructionsType = "批量删除")
    public Object deleteAll() throws Exception {
        Map<String, Object> map = new HashMap<String, Object>();
        String errInfo = "success";
        PageData pd = new PageData();
        pd = this.getPageData();
        pd.put("OPERATOR", Jurisdiction.getUsername());    //修改人
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        String DATA_IDS = pd.getString("DATA_IDS");
        if (Tools.notEmpty(DATA_IDS)) {
            String[] ArrayDATA_IDS = DATA_IDS.split(",");
            pd.put("ArrayDATA_IDS", ArrayDATA_IDS);    //待删除ids
            coursestudyvideorecordService.deleteAll(pd);
            errInfo = "success";
        } else {
            errInfo = "error";
        }
        map.put("result", errInfo);                //返回结果
        return map;
    }

    /**
     * 导出到excel
     *
     * @param
     * @throws Exception
     */
    @RequestMapping(value = "/excel")
    // @RequiresPermissions("toExcel")
    @LogAnno(menuType = "手机", menuServer = "课程学习视频记录", instructionsOperate = "课程学习视频记录", instructionsType = "导出到excel")
    public ModelAndView exportExcel() throws Exception {
        ModelAndView mv = new ModelAndView();
        PageData pd = new PageData();
        pd = this.getPageData();
        Map<String, Object> dataMap = new HashMap<String, Object>();
        List<String> titles = new ArrayList<String>();
        titles.add("课程ID");    //1
        titles.add("视频课件ID");    //2
        titles.add("学员ID");    //3
        titles.add("播放时间");    //4
        titles.add("播放次数");    //5
        titles.add("添加人");    //6
        titles.add("添加时间");    //7
        titles.add("修改人");    //8
        titles.add("修改时间");    //9
        titles.add("是否删除(0:有效 1：删除)");    //10
        titles.add("企业ID");    //11
        dataMap.put("titles", titles);
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());    //企业ID
        List<PageData> varOList = coursestudyvideorecordService.listAll(pd);
        List<PageData> varList = new ArrayList<PageData>();
        for (int i = 0; i < varOList.size(); i++) {
            PageData vpd = new PageData();
            vpd.put("var1", varOList.get(i).getString("CURRICULUM_ID"));        //1
            vpd.put("var2", varOList.get(i).getString("VIDEOCOURSEWARE_ID"));        //2
            vpd.put("var3", varOList.get(i).getString("USER_ID"));        //3
            vpd.put("var4", varOList.get(i).get("RESOURCETIME").toString());    //4
            vpd.put("var5", varOList.get(i).get("PLAYCOUNT").toString());    //5
            vpd.put("var6", varOList.get(i).getString("CREATOR"));        //6
            vpd.put("var7", varOList.get(i).getString("CREATTIME"));        //7
            vpd.put("var8", varOList.get(i).getString("OPERATOR"));        //8
            vpd.put("var9", varOList.get(i).getString("OPERATTIME"));        //9
            vpd.put("var10", varOList.get(i).getString("ISDELETE"));        //10
            vpd.put("var11", varOList.get(i).getString("CORPINFO_ID"));        //11
            varList.add(vpd);
        }
        dataMap.put("varList", varList);
        ObjectExcelView erv = new ObjectExcelView();
        mv = new ModelAndView(erv, dataMap);
        return mv;
    }

}
