package com.zcloud.service.eightwork.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.zcloud.entity.Page;
import com.zcloud.entity.PageData;
import com.zcloud.mapper.datasource.eightwork.*;
import com.zcloud.service.eightwork.HotworkService;
import com.zcloud.util.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;
import com.zcloud.service.eightwork.HighworkService;

import java.text.DecimalFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @author fangjiakai
 * @date 2024/01/17 11:30
 */
@Service
@Transactional //开启事物
public class HighworkServiceImpl implements HighworkService {

    @Autowired
    private HighworkMapper highworkMapper;
    @Autowired
    private EightWorkTaskFlowMapper eightWorkTaskFlowMapper;
    @Autowired
    private EightWorkFlowLogMapper eightWorkFlowLogMapper;
    @Autowired
    private HighworkSignMapper highworkSignMapper;
    @Autowired
    private HighworkToMeasuresMapper highworkToMeasuresMapper;
    @Autowired
    private EightWorkVideoManagerMapper eightworkvideomanagerMapper;
    @Autowired
    private Smb smb;
    @Autowired
    private SendMessageUtil sendMessageUtil;

    private final String primary_key = "HIGHWORK_ID";
    private final String work_type = "HIGHWORK";

    @Override
    @Transactional
    public void save(PageData pd) throws Exception {
        // 通过票
        if ("1".equals(pd.get("APPLY_STATUS"))) {
            PageData pd2 = new PageData();
            Calendar calendar = Calendar.getInstance();
            DecimalFormat dft = new DecimalFormat("00");
            int year = calendar.get(Calendar.YEAR);
            String month = dft.format(calendar.get(Calendar.MONTH) + 1);
            String day = dft.format(calendar.get(Calendar.DAY_OF_MONTH));
            pd2.put("CREATDATE", year + "-" + month + "-" + day);
            pd2.put("CORPINFO_ID", pd.get("CORPINFO_ID"));
            pd2 = highworkMapper.getCode(pd2);    //根据ID读取
            String code = "GC" + year + month + day + dft.format((Integer.parseInt(pd2.get("code").toString()) + 1));
            pd.put("CHECK_NO", code);
        }
        pd.put(primary_key, UuidUtil.get32UUID());    //主键
        pd.put("CREATTIME", DateUtil.date2Str(new Date()));    //添加时间
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        pd.put("ISDELETE", "0");    //是否删除 1-是  0-否
        highworkMapper.save(pd);

        if ("1".equals(pd.get("APPLY_STATUS"))) {
            // 关联作业票
            if (Tools.notEmpty(pd.getString("SPECIAL_WORK"))) {

                String[] specialWorks = pd.getString("SPECIAL_WORK").split(",");
                if (specialWorks.length != 0) {
                    for (int i = 0; i < specialWorks.length; i++) {
                        String[] workNameANo = specialWorks[i].split(" ");
                        changeOtherWorkCard(workNameANo, pd.getString("CORPINFO_ID"), "高处作业 " + pd.getString("CHECK_NO"));
                    }
                }
            }

            PageData flow = getStep(pd.get("TASK_ID"), "1");
            saveLog(pd, pd.getString("CREATOR"), "1");
            saveNextSigner(pd, flow);
            if (Tools.notEmpty(pd.getString("PLS_ID"))) {
                setPosition(pd);
            }
        }
    }

    @Transactional
    public void changeOtherWorkCard(String[] workNameANo, String CORPINFO_ID, String code) {
        PageData pageData = new PageData();
        pageData.put("CORPINFO_ID", CORPINFO_ID);
        if (workNameANo.length == 1) {
            // 手动 填写的作业票
            PageData pd1 = new PageData();
            pd1.put("CHECK_NO", workNameANo[0]);
            pd1 = highworkMapper.findInfoFromFlowLogByIdAndCheckNo(pageData);
            if (pd1 != null) {
                //
                if ("CONFINEDSPACE".equals(pd1.getString("WORK_TYPE"))) workNameANo = new String[]{"受限作业", pd1.getString("CHECK_NO")};
                if ("HIGHWORK".equals(pd1.getString("WORK_TYPE"))) workNameANo = new String[]{"高处作业", pd1.getString("CHECK_NO")};
                if ("BLINDBOARD".equals(pd1.getString("WORK_TYPE"))) workNameANo = new String[]{"盲板作业", pd1.getString("CHECK_NO")};
                if ("ELECTRICITY".equals(pd1.getString("WORK_TYPE"))) workNameANo = new String[]{"临时用电", pd1.getString("CHECK_NO")};
                if ("HOISTING".equals(pd1.getString("WORK_TYPE"))) workNameANo = new String[]{"吊装作业", pd1.getString("CHECK_NO")};
                if ("BREAKGROUND".equals(pd1.getString("WORK_TYPE"))) workNameANo = new String[]{"动土作业", pd1.getString("CHECK_NO")};
                if ("CUTROAD".equals(pd1.getString("WORK_TYPE"))) workNameANo = new String[]{"断路作业", pd1.getString("CHECK_NO")};
                if ("HOTWORK".equals(pd1.getString("WORK_TYPE"))) workNameANo = new String[]{"动火作业", pd1.getString("CHECK_NO")};
            } else return;
        }
        new PageData();
        PageData work;
        switch (workNameANo[0]) {
            case "动火作业":
                pageData.put("table", "bus_hotwork");
                pageData.put("PRIMARY_KEY", "HOTWORK_ID");
                break;
            case "受限作业":
                pageData.put("table", "bus_confinedspace");
                pageData.put("PRIMARY_KEY", "CONFINEDSPACE_ID");
                break;
            case "高处作业":
                pageData.put("table", "bus_highwork");
                pageData.put("PRIMARY_KEY", "HIGHWORK_ID");
                break;
            case "临时用电":
                pageData.put("table", "bus_electricity");
                pageData.put("PRIMARY_KEY", "ELECTRICITY_ID");
                break;
            case "动土作业":
                pageData.put("table", "bus_breakground");
                pageData.put("PRIMARY_KEY", "BREAKGROUND_ID");
                break;
            case "吊装作业":
                pageData.put("table", "bus_hoisting");
                pageData.put("PRIMARY_KEY", "HOISTING_ID");
                break;
            case "断路作业":
                pageData.put("table", "bus_cutroad");
                pageData.put("PRIMARY_KEY", "CUTROAD_ID");
                break;
            case "盲板作业":
                pageData.put("table", "bus_blindboard");
                pageData.put("PRIMARY_KEY", "BLINDBOARD_ID");
                break;
        }
        pageData.put("CHECK_NO", workNameANo[1]);
        work = highworkMapper.findInfoByIdAndCheckNo(pageData);
        work.putAll(pageData);
        if (Tools.notEmpty(work.getString("SPECIAL_WORK"))) {
            String checkNo = work.getString("SPECIAL_WORK");
            work.put("SPECIAL_WORK", checkNo + "," + code);
        } else {
            work.put("SPECIAL_WORK", code);
        }
        work.put("ID", work.getString(pageData.getString("PRIMARY_KEY")));
        highworkMapper.updCheckNoInfo(work);
    }

    @Override
    @Transactional
    public void edit(PageData pd) throws Exception {
        pd.put("OPERATTIME", DateUtil.date2Str(new Date()));    //修改时间
        // 通过票
        if ("1".equals(pd.get("APPLY_STATUS"))) {
            PageData pd2 = new PageData();
            Calendar calendar = Calendar.getInstance();
            DecimalFormat dft = new DecimalFormat("00");
            int year = calendar.get(Calendar.YEAR);
            String month = dft.format(calendar.get(Calendar.MONTH) + 1);
            String day = dft.format(calendar.get(Calendar.DAY_OF_MONTH));
            pd2.put("CREATDATE", year + "-" + month + "-" + day);
            pd2.put("CORPINFO_ID", pd.get("CORPINFO_ID"));
            pd2 = highworkMapper.getCode(pd2);    //根据ID读取
            String code = "GC" + year + month + day + dft.format((Integer.parseInt(pd2.get("code").toString()) + 1));
            pd.put("CHECK_NO", code);
        }
        highworkMapper.edit(pd);

        if ("1".equals(pd.get("APPLY_STATUS"))) {
            pd.put("STEP_ID", 1);
            highworkMapper.editStep(pd);
            if (Tools.notEmpty(pd.getString("SPECIAL_WORK"))) {

                String[] specialWorks = pd.getString("SPECIAL_WORK").split(",");
                if (specialWorks.length != 0) {
                    for (int i = 0; i < specialWorks.length; i++) {
                        String[] workNameANo = specialWorks[i].split(" ");
                        changeOtherWorkCard(workNameANo, pd.getString("CORPINFO_ID"), "高处作业 " + pd.getString("CHECK_NO"));
                    }
                }
            }
            PageData flow = getStep(pd.get("TASK_ID"), "1");
            saveLog(pd, pd.getString("CREATOR"), "1");
            saveNextSigner(pd, flow);
            if (Tools.notEmpty(pd.getString("PLS_ID"))) {
                setPosition(pd);
            }
        }
    }

    @Override
    public void delete(PageData pd) throws Exception {
        highworkMapper.delete(pd);
    }

    @Override
    public List<PageData> list(Page page) throws Exception {
        return highworkMapper.datalistPage(page);
    }


    /*
     * 下一步
     */
    @Override
    @Transactional
    public void nextStep(PageData pd, MultipartFile[] files) throws Exception {
        PageData work = this.findById(pd);
        work.putAll(pd);
        List<String> filePaths = new ArrayList<>();
        for (int i = 0; i < files.length; i++) {
            if (files[i] != null) {
                //保存签名文件
                String ffile = DateUtil.getDays();
                String fileName = UuidUtil.get32UUID() + files[i].getOriginalFilename().substring(files[i].getOriginalFilename().lastIndexOf("."));
                smb.sshSftp(files[i], fileName, Const.FILEPATHFILE + work.getString("CORPINFO_ID") + "/" + ffile);
                filePaths.add(Const.FILEPATHFILE + work.getString("CORPINFO_ID") + "/" + ffile + "/" + fileName);
            }
        }
        PageData flow = getStep(work.get("TASK_ID"), work.get("STEP_ID"));
        work.put("STEP_ID", flow.get("NEXT_STEP_ID"));
        highworkMapper.editVideo(work);

        //保存签名信息
        PageData sign = new PageData();
        sign.put(primary_key, work.get(primary_key));
        sign.put("STEP_ID", work.get("STEP_ID"));
        sign.put("SIGN_USER_ID", work.get("USER_ID"));
        sign.put("SIGN_TIME", work.getString("SIGNTIME"));
        sign.put("SIGN_PATH", String.join(",", filePaths));
        sign.put("DESCR", work.get("DESCR"));
        sign.put("IMG_PATH", work.get("IMG_PATH"));

        highworkSignMapper.edit(sign);

        if (work.get("MEASURES") != null && !work.get("MEASURES").equals("")) { //安全措施确认步骤
            saveMeasures(work);
        }

        List<PageData> unsignedList = highworkSignMapper.checkUnsigned(sign);//当前步骤未签名人列表
        if ((unsignedList == null || unsignedList.size() == 0) && pd.getString("APPLY_STATUS").equals("1")) {//如果没有未签人 则跳转下一步

            //保存日志
            saveLog(work, work.getString("USER_ID"), "1");

            PageData currentflow = getCurrentFlow(work);
            work.put("STEP_ID", currentflow.get("STEP_ID"));
            highworkMapper.editStep(work);

            //消息推送
            switch(currentflow.getString("NEXT_STEP_ID")){
                case "8":
                    sendMessageForFinishedGK(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_Y01",
                            work.getString("CHECK_NO"),currentflow.getString("NEXT_STEP_NAME"));
                    break;
                case "9":
                    sendMessageForFinishedGK(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_Y02",
                            work.getString("CHECK_NO"),currentflow.getString("NEXT_STEP_NAME"));
                    break;
                case "25":
                    sendMessageForFinishedGK(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_Y03",
                            work.getString("CHECK_NO"),currentflow.getString("NEXT_STEP_NAME"));
                    break;
                case "11":
                    sendMessageForFinishedGK(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_Y04",
                            work.getString("CHECK_NO"),currentflow.getString("NEXT_STEP_NAME"));
                    break;
                case "15":
                    sendMessageForFinishedGK(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_Y05",
                            work.getString("CHECK_NO"),currentflow.getString("NEXT_STEP_NAME"));
                    break;
                case "99":
                    eightworkvideomanagerMapper.editStatus(work);
                    sendMessageForFinishedGK(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_Y06",
                            work.getString("CHECK_NO"),null);
                    break;
                default :
                    break;
            }

            if (work.get("PREPARERS") != null && !work.get("PREPARERS").equals("")) { //如果是设置安全措施确认人步骤
                savePreparers(work, currentflow);
            }
            saveNextSigner(work, currentflow);
        } else if (pd.getString("APPLY_STATUS").equals("-1")) {
            //消息推送
            switch(work.getString("STEP_ID")){
                case "8":
                    sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_N02",
                            work.getString("CHECK_NO"),work.getString("CONFIRM_USER_NAME"));
                    break;
                case "9":
                    sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_N03",
                            work.getString("CHECK_NO"),work.getString("LEADER_USER_NAME"));
                    break;
                case "25":
                    sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_N04",
                            work.getString("CHECK_NO"),work.getString("AUDIT_USER_NAME"));
                    break;
                case "11":
                    sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_N05",
                            work.getString("CHECK_NO"),work.getString("APPROVE_USER_NAME"));
                    break;
                case "15":
                    sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"GK_N06",
                            work.getString("CHECK_NO"),work.getString("ACCEPT_USER_NAME"));
                    break;
                default :
                    break;
            }
            //保存日志
            saveLog(work, work.getString("USER_ID"), "-1");
            eightworkvideomanagerMapper.editStatus(work);

            work.put("STEP_ID", -1);
            highworkMapper.editStep(work);
        }
        // 作业 监护人停止
        else if("-3".equals(pd.getString("APPLY_STATUS"))){
            //保存日志
            saveLog(work,work.getString("USER_ID"),"-3");
            eightworkvideomanagerMapper.editStatus(work);
            work.put("STEP_ID",-3);
            highworkMapper.editStep(work);
            sendMessageForFinished(work.getString("CORPINFO_ID"),work.getString("CREATOR"),"EIGHTWORK_STOP",work.getString("CHECK_NO"),null);
        }
    }

    private PageData getCurrentFlow(PageData work) throws Exception {
        PageData flow = new PageData();
        flow.put("TASK_ID", work.get("TASK_ID"));
        flow.put("STEP_ID", work.get("STEP_ID"));
        flow = eightWorkTaskFlowMapper.getStep(flow);
        if ("1".equals(flow.getString("CAN_SKIP")) && (work.get(flow.get("NEXT_ACTOR_FIELD")) == null || work.get(flow.get("NEXT_ACTOR_FIELD")).equals(""))) {
            work.put("STEP_ID", flow.get("NEXT_STEP_ID"));
            return getCurrentFlow(work);
        } else {
            return flow;
        }
    }

    @Override
    public PageData findById(PageData pd) throws Exception {
        PageData pageData = highworkMapper.findById(pd);
        return pageData;
    }

    @Override
    public PageData listSignFinished(PageData pd) throws Exception {
        Map<String, List<PageData>> rmap = new HashMap<>();
        List<PageData> varList = highworkSignMapper.listAll(pd);
        if (varList != null && !varList.isEmpty()) {
            varList.stream().forEach(item -> {
                PageData sign = new PageData();
                sign.put("SIGN_PATH", item.getString("SIGN_PATH").split(","));
                sign.put("SIGN_TIME", item.getString("SIGN_TIME").split(","));
                sign.put("IMG_PATH", item.getString("IMG_PATH"));
                sign.put("DESCR", item.getString("DESCR") != null ? item.getString("DESCR") : "无");
                if (rmap.containsKey(item.getString("CODE"))) {
                    rmap.get(item.getString("CODE")).add(sign);
                } else {
                    List<PageData> signs = new ArrayList<>();
                    signs.add(sign);
                    rmap.put(item.getString("CODE"), signs);
                }
            });
        }
        PageData rpd = new PageData();
        if (rmap != null && !rmap.isEmpty()) {
            rpd.putAll(rmap);
        }
        return rpd;
    }

    @Override
    public PageData checkWorkCount(PageData pd) {
        PageData rpd = new PageData();
        List<PageData> varList = highworkMapper.checkWorkCount(pd);

        if (varList != null && !varList.isEmpty()) {
            Map<String, String> newMap = varList.stream().collect(Collectors.toMap(map -> map.getString("CODE"), map -> map.getString("COUNT")));

            rpd.putAll(newMap);
        }
        return rpd;
    }

    @Override
    public List<PageData> listAllMeasures() throws Exception {
        return highworkMapper.listAllMeasures();

    }

    @Override
    public List<PageData> listAllMeasuresForSign(PageData pd) throws Exception {
        return highworkToMeasuresMapper.listAllMeasuresForSign(pd);

    }

    @Override
    public List<PageData> listSignFinishMeasures(PageData pd) throws Exception {
        return highworkToMeasuresMapper.listSignFinishMeasures(pd);
    }


    @Override
    public List<PageData> getFlowList(PageData pd) throws Exception {
        pd = findById(pd);
        return highworkMapper.getFlowList(pd);
    }

    @Override
    public ReturnMap getMapList() throws Exception {
        ReturnMap returnMap = new ReturnMap();
        PageData pd = new PageData();
        pd.put("CORPINFO_ID", Jurisdiction.getCORPINFO_ID());
        returnMap.put("varList", highworkMapper.getMapList(pd));
        return returnMap;
    }

    private void saveNextSigner(PageData pd, PageData flow) throws Exception {

        pd.put("STEP_ID", flow.get("NEXT_STEP_ID"));

        if (pd.get(flow.get("NEXT_ACTOR_FIELD")) == null || pd.get(flow.get("NEXT_ACTOR_FIELD")).equals("")) {
            return;
        }
        //提前保存下一步签字人
        List<PageData> signers = new ArrayList<>();
        PageData signer = new PageData();
        signer.put("HIGHWORK_SIGN_ID", UuidUtil.get32UUID()); // 主键
        signer.put(primary_key, pd.get(primary_key));
        signer.put("CORPINFO_ID", pd.get("CORPINFO_ID"));
        signer.put("SIGN_USER_ID", pd.get(flow.get("NEXT_ACTOR_FIELD")));
        signer.put("STEP_ID", flow.get("NEXT_STEP_ID"));
        signers.add(signer);
        highworkSignMapper.saveBatch(signers);
//        sendMessageForNext(pd.getString("CORPINFO_ID"), pd.getString(flow.get("NEXT_ACTOR_FIELD")), pd.getString("CHECK_NO"), flow.getString("NEXT_STEP_NAME"));

    }

    private void saveMeasures(PageData pd) {
        List<JSONObject> list = (List<JSONObject>) JSON.parse(pd.get("MEASURES").toString());
        for (JSONObject json : list) {
            PageData measure = new PageData();
            measure.put("HIGHWORKTOMEASURES_ID", json.get("HIGHWORKTOMEASURES_ID"));
            measure.put("STATUS", json.get("STATUS"));
            measure.put("SIGN_PATH", json.get("SIGN_PATH"));
            measure.put("SIGN_TIME", json.get("SIGN_TIME"));
            measure.put("IMG_PATH", json.get("IMG_PATH"));
            highworkToMeasuresMapper.edit(measure);
        }
    }

    private void savePreparers(PageData pd, PageData flow) {
        List<PageData> signers = new ArrayList<>();
        List<JSONObject> list = (List<JSONObject>) JSON.parse(pd.get("PREPARERS").toString());
        for (JSONObject json : list) {
            PageData preparer = new PageData();
            preparer.put("HIGHWORKTOMEASURES_ID", UuidUtil.get32UUID()); // 主键
            preparer.put("HIGHWORK_ID", pd.get("HIGHWORK_ID"));
            preparer.put("BUS_HIGHWORK_MEASURES_ID", json.get("BUS_HIGHWORK_MEASURES_ID"));
            preparer.put("CONFIRM_ID", json.get("USER_ID"));
            signers.add(preparer);
        }
        if (signers.size() > 0) {
            highworkToMeasuresMapper.saveBatch(signers);

            //获取所有需要签名人
            List<String> fieldList = signers.stream().map(map -> map.getString("CONFIRM_ID")).collect(Collectors.toList());
            Set<String> fieldSet = new HashSet<>(fieldList); //去重

            List<String> uniqueList = new ArrayList<>(fieldSet);
            List<PageData> nextSigners = new ArrayList<>();
            uniqueList.forEach(item -> { // 保存下一步需要签名的人
                PageData signer = new PageData();
                signer.put("HIGHWORK_SIGN_ID", UuidUtil.get32UUID()); // 主键
                signer.put(primary_key, pd.get(primary_key));
                signer.put("CORPINFO_ID", pd.get("CORPINFO_ID"));
                signer.put("SIGN_USER_ID", item);
                signer.put("STEP_ID", flow.get("NEXT_STEP_ID"));
                nextSigners.add(signer);
//                try {
//                    sendMessageForNext(pd.getString("CORPINFO_ID"), item, pd.getString("CHECK_NO"), flow.getString("NEXT_STEP_NAME"));
//                } catch (Exception e) {
//                    throw new RuntimeException(e);
//                }
            });

            highworkSignMapper.saveBatch(nextSigners);
        }
    }

    private PageData getStep(Object TASK_ID, Object STEP_ID) throws Exception {
        PageData flow = new PageData();
        flow.put("TASK_ID", TASK_ID);
        flow.put("STEP_ID", STEP_ID);
        flow = eightWorkTaskFlowMapper.getStep(flow);
        return flow;
    }

    private void saveLog(PageData pd, String act_user, String status) throws Exception {
        PageData log = new PageData();
        log.put("LOG_ID", UuidUtil.get32UUID());
        log.put("WORK_ID", pd.get(primary_key));
        log.put("TASK_ID", pd.get("TASK_ID"));
        log.put("STEP_ID", pd.get("STEP_ID"));
        log.put("CORPINFO_ID", pd.get("CORPINFO_ID"));
        log.put("CHECK_NO", pd.get("CHECK_NO"));
        log.put("ACT_USER", act_user);
        log.put("ACT_TIME", DateUtil.date2Str(new Date()));
        log.put("STATUS", status);
        log.put("WORK_TYPE", work_type);
        eightWorkFlowLogMapper.save(log);
    }


    private void setPosition(PageData pd) throws Exception {
        JSONObject body = PLSUtil.getRyRegionInfo(pd.getString("CORPINFO_ID"), Integer.parseInt(pd.getString("PLS_ID")));
        List pointList = (List) ((Map) body.get("data")).get("list");
        List<String> positions = PLSUtil.getRandomPointInPolygon(pointList);
        pd.put("WORK_POSITION", String.join(",", positions));
        highworkMapper.setPosition(pd);
    }

    private void sendMessageForNext(String corpinfo_id, String userId, String number, String flow_name) throws Exception {
        PageData mes = new PageData();
        mes.put("RECEIVER_ID", userId);// 收信人userid
        mes.put("templateCode", "EIGHTWORK_REMINDER");// 短信模板编码
        mes.put("CORPINFO_ID", corpinfo_id);// 企业id

        // 参数集合
        List<PageData> paramsList = new ArrayList<PageData>();
        // 第1个参数
        PageData params1 = new PageData();
        params1.put("name", "number");// 存入短信模板中的参数名称
        params1.put("value", number);// 存入上面参数名称所传递的值
        paramsList.add(params1);

        PageData params2 = new PageData();
        params2.put("name", "type");// 存入短信模板中的参数名称
        params2.put("value", "高处作业");// 存入上面参数名称所传递的值
        paramsList.add(params2);

        PageData params3 = new PageData();
        params3.put("name", "flow");// 存入短信模板中的参数名称
        params3.put("value", flow_name);// 存入上面参数名称所传递的值
        paramsList.add(params3);
        try {
            sendMessageUtil.sendMessages(mes, paramsList);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    private void sendMessageForFinishedGK(String corpinfo_id,String userId,String template,String number,String stepName) throws Exception {
        PageData mes = new PageData();
        mes.put("RECEIVER_ID", userId);// 收信人userid
        mes.put("templateCode", template);// 短信模板编码
        mes.put("CORPINFO_ID", corpinfo_id);// 企业id

        // 参数集合
        List<PageData> paramsList = new ArrayList<PageData>();
        if("GK_Y06".equals(template)){
            // 第1个参数
            PageData params = new PageData();
            params.put("name", "number");// 存入短信模板中的参数名称
            params.put("value", number);// 存入上面参数名称所传递的值
            paramsList.add(params);

            PageData params1 = new PageData();
            params1.put("name", "type");// 存入短信模板中的参数名称
            params1.put("value", "高空作业");// 存入上面参数名称所传递的值
            paramsList.add(params1);
        }else{
            // 第1个参数
            PageData params = new PageData();
            params.put("name", "number");// 存入短信模板中的参数名称
            params.put("value", number);// 存入上面参数名称所传递的值
            paramsList.add(params);

            PageData params1 = new PageData();
            params1.put("name", "params1");// 存入短信模板中的参数名称
            params1.put("value", "高空作业");// 存入上面参数名称所传递的值
            paramsList.add(params1);

            PageData params2 = new PageData();
            params2.put("name", "params2");// 存入短信模板中的参数名称
            params2.put("value", stepName);// 存入上面参数名称所传递的值
            paramsList.add(params2);

            PageData params3 = new PageData();
            params3.put("name", "params3");// 存入短信模板中的参数名称
            params3.put("value", "确认审批");// 存入上面参数名称所传递的值
            paramsList.add(params3);
        }
        try {
            sendMessageUtil.sendMessages(mes, paramsList);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    private void sendMessageForFinished(String corpinfo_id,String userId,String template,String number,String stepName) throws Exception {
        PageData mes = new PageData();
        mes.put("RECEIVER_ID", userId);// 收信人userid
        mes.put("templateCode", template);// 短信模板编码
        mes.put("CORPINFO_ID", corpinfo_id);// 企业id

        // 参数集合
        List<PageData> paramsList = new ArrayList<PageData>();
        // 第1个参数
        PageData params = new PageData();
        params.put("name", "params1");// 存入短信模板中的参数名称
        params.put("value", number);// 存入上面参数名称所传递的值
        paramsList.add(params);

        PageData params1 = new PageData();
        params1.put("name", "params2");// 存入短信模板中的参数名称
        params1.put("value", "高空作业");// 存入上面参数名称所传递的值
        paramsList.add(params1);

        PageData params2 = new PageData();
        params2.put("name", "params3");// 存入短信模板中的参数名称
        params2.put("value", stepName);// 存入上面参数名称所传递的值
        paramsList.add(params2);

        try {
            sendMessageUtil.sendMessages(mes, paramsList);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }
}
