package com.zcloud.util;

/**
 * @author fangjiakai
 * @date 2022/11/22 16:51
 */
public class Levenshtein {
    private int compare(String str, String target) {
        int d[][];              // 矩阵
        int n = str.length();
        int m = target.length();
        int i;                  // 遍历str的
        int j;                  // 遍历target的
        char ch1;               // str的
        char ch2;               // target的
        int temp;               // 记录相同字符,在某个矩阵位置值的增量,不是0就是1
        if (n == 0) {
            return m;
        }
        if (m == 0) {
            return n;
        }
        d = new int[n + 1][m + 1];
        for (i = 0; i <= n; i++) {                       // 初始化第⼀列
            d[i][0] = i;
        }
        for (j = 0; j <= m; j++) {                       // 初始化第⼀⾏
            d[0][j] = j;
        }
        for (i = 1; i <= n; i++) {                       // 遍历str
            ch1 = str.charAt(i - 1);
            // 去匹配target
            for (j = 1; j <= m; j++) {
                ch2 = target.charAt(j - 1);
                if (ch1 == ch2 || ch1 == ch2 + 32 || ch1 + 32 == ch2) {
                    temp = 0;
                } else {
                    temp = 1;
                }
                // 左边+1,上边+1, 左上⾓+temp取最⼩
                d[i][j] = min(d[i - 1][j] + 1, d[i][j - 1] + 1, d[i - 1][j - 1] + temp);
            }
        }
        return d[n][m];
    }

    private int min(int one, int two, int three) {
        return (one = one < two ? one : two) < three ? one : three;
    }

    /**
     * 获取两字符串的相似度
     */
    public float getSimilarityRatio(String str, String target) {
        return 1 - (float) compare(str, target) / Math.max(str.length(), target.length());
    }

    public static void main(String[] args) {
        Levenshtein lt = new Levenshtein();
        long t1 = System.currentTimeMillis();
        String str = "阿萨德水电费第三方干点啥风撒旦法萨芬干点啥风格的风格是大法官撒旦法撒旦法格的双方各得分公司的风格的双方各第三方";
        String target = "阿萨德水电费第三方干点啥风撒旦法萨芬干点啥风格暗示法撒旦法士大夫分公司的分公司的分公司的故事都发给第三方割发代首孤独颂歌第三个是范德萨发的风格是大法官撒旦法撒旦法格的双方各得分公司的风格的双方各第三方";
        System.out.println("similarityRatio=" + lt.getSimilarityRatio(str, target));
        long t2= System.currentTimeMillis();
    }
}
